;; Generated package description from gnat-compiler.el  -*- no-byte-compile: t -*-
(define-package "gnat-compiler" "1.0.0.0.20221228.92523" "Support for running GNAT tools" '((emacs "25.3") (wisi "4.1")) :commit "8ca2e5bcd244c8d191035c3c4e011e31e534738e" :url "https://elpa.gnu.org/packages/gnat-compiler.html" :authors '(("Stephen Leake" . "stephen_leake@member.fsf.org")) :maintainer '("Stephen Leake" . "stephen_leake@member.fsf.org"))
